#[non_exhaustive]pub enum PortabilityError {
IncrementDecrement,
}Expand description
Cause of an error because an expression contains a non-portable construct
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IncrementDecrement
An increment or decrement operator is used while the portable option
is on.